.. Manrododex documentation master file, created by
   sphinx-quickstart on Sat Sep 10 10:10:47 2022.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

======================================
Welcome to Manrododex's documentation!
======================================

Getting started
===============

.. toctree::
    :maxdepth: 1

    manual/install
    manual/compatibility
    manual/automating
    manual/args

Miscellaneous
=============

.. toctree::
    :maxdepth: 1

    manual/FAQ
    manual/license

* :ref:`genindex`

